@@ -1,6 +1,6 @@
 package URI::Fast;
 
-our $XS_VERSION = our $VERSION = '0.39';
+our $XS_VERSION = our $VERSION = '0.40';
 $VERSION =~ tr/_//;
 
 use utf8;
@@ -370,8 +370,13 @@ parameter to C<undef> deletes the parameter from the URI.
   my @value_list   = $uri->param('foo');   # foo appears twice
   my $value_scalar = $uri->param('foo');   # croaks; expected single value but foo has multiple
 
-  # Delete 'foo'
-  $uri->param('foo', undef);
+  # Delete parameter
+  $uri->param('foo', undef); # deletes foo
+
+  # Ambiguous cases
+  $uri->param('foo', '');  # foo=
+  $uri->param('foo', '0'); # foo=0
+  $uri->param('foo', ' '); # foo=%20
 
 Both '&' and ';' are treated as separators for key/value parameters when
 parsing the query string. An optional third parameter explicitly selects the
@@ -476,6 +481,13 @@ non-ASCII characters are decoded but reserved characters are not. When
 returning a list or reference of the deconstructed field, individual values are
 decoded of both reserved and non-ASCII characters.
 
+=head2 '+' vs '%20'
+
+Although no longer part of the standard, C<+> is commonly used as the encoded
+space character (rather than C<%20>); it I<is> still official to the
+C<application/x-www-form-urlencoded> type, and is treated as a space by
+L</decode>.
+
 =head2 encode
 
 Percent-encodes a string for use in a URI. By default, both reserved and UTF-8
